Hypermedia Client
=================

Hypermedia client is a proxy for direct URL-access to a hypermedia resource. It
currently allows a python developer to interact with a SIREN-producing service
as though the objects were local to the application.
